@@ -38,7 +38,7 @@ class NANONETSOCR():
             response = requests.request("POST", url = self.endpoint, headers=headers, files=files, auth=requests.auth.HTTPBasicAuth(self.token, ''))
             return response.text
         
-    def image_to_string(self, url, formatting = 'none', space_size = 11, line_height = 60, line_threshold = 'high'):
+    def image_to_string(self, url, formatting = 'none', space_size = 11, line_height = 60, line_threshold = 'low'):
         if formatting == 'none':
             return json.loads(self.convert_to_prediction(url))['results'][0]['page_data'][0]['raw_text']
         if formatting == 'lines':
@@ -104,10 +104,10 @@ class NANONETSOCR():
 
                     else:
                         lines.append(line)
-                        while x['ymax'] - y2 > line_height:
+                        while x['ymax'] - y > line_height*2:
                             lines.append("")
                             spaces.append(0)
-                            y2 = y2 + line_height
+                            y = y + line_height
                         
                         line = x['text']
                         y = x['ymax']
@@ -140,7 +140,7 @@ class NANONETSOCR():
     def image_to_boxes(self, url):
         return json.loads(self.convert_to_prediction(url))['results'][0]['page_data'][0]['words']
         
-    def image_to_searchablepdf(self, url, filename = 'did not give a filename', formatting = 'lines and spaces',space_size = 11, line_height = 60, line_threshold = 'high'):
+    def image_to_searchablepdf(self, url, filename = 'did not give a filename', formatting = 'lines and spaces',space_size = 11, line_height = 60, line_threshold = 'low'):
         text = self.image_to_string(url, formatting = formatting, space_size = space_size, line_height = line_height, line_threshold = line_threshold)
         if filename == 'did not give a filename':
             filename = url + '.pdf'
@@ -165,7 +165,7 @@ class NANONETSOCR():
                 pdf.ln()
 
             for wrap in lines:
-                pdf.cell(0, fontsize_mm, wrap, ln=1)
+                pdf.multi_cell(0, fontsize_mm, wrap)
 
         pdf.output(filename, 'F')
         print(filename + ' created in current directory')
@@ -232,7 +232,7 @@ class NANONETSOCR():
             
             i = 1
             
-            if not(len(response.json()["result"]) == 1 and len(response.json()["result"][0]["prediction"] ==1)):
+            if not(len(response.json()["result"]) == 1 and len(response.json()["result"][0]["prediction"]) ==1):
                 with open(filename, "w") as my_empty_csv:
                     pass
                 
@@ -267,13 +267,13 @@ class NANONETSOCR():
                 maxrow = 0
                 maxcol = 0
 
-                for el in table['prediction'][0]['cells']:
+                for el in table['cells']:
                     maxrow = max(el['row'],maxrow)
                     maxcol = max(el['col'], maxcol)
 
                 df = pd.DataFrame(np.zeros([maxrow, maxcol])*np.nan)
 
-                for el in table['prediction'][0]['cells']:
+                for el in table['cells']:
                     row = el['row'] - 1
                     col = el['col'] - 1
                     df.iloc[row,col] = el['text']
@@ -281,7 +281,7 @@ class NANONETSOCR():
                 df.to_csv(filename,index=False, header=False)
                 print(filename + ' created in current directory')
             
-    def pdf_to_string(self, url, formatting = 'none', space_size = 11, line_height = 50, line_threshold = 'high'):
+    def pdf_to_string(self, url, formatting = 'none', space_size = 11, line_height = 50, line_threshold = 'low'):
         if formatting == 'none':
             result = ''
             for el in json.loads(self.convert_to_prediction(url))['results'][0]['page_data']:
@@ -364,10 +364,10 @@ class NANONETSOCR():
                             prev = x['xmax']
                         else:
                             lines.append(line)
-                            while x['ymax'] - y2 > line_height:
+                            while x['ymax'] - y > line_height*2:
                                 lines.append("")
                                 spaces.append(0)
-                                y2 = y2 + line_height
+                                y = y + line_height
                             
                             line = x['text']
                             y = x['ymax']
@@ -404,7 +404,7 @@ class NANONETSOCR():
             pages.append(result)
         return pages
     
-    def pdf_to_searchablepdf(self, url, filename = 'did not give a filename', formatting = 'lines and spaces',space_size = 11, line_height = 50, line_threshold = 'high'):
+    def pdf_to_searchablepdf(self, url, filename = 'did not give a filename', formatting = 'lines and spaces',space_size = 11, line_height = 50, line_threshold = 'low'):
         texts = self.pdf_to_string(url, formatting = formatting, space_size = space_size, line_height = line_height, line_threshold = line_threshold)
         if filename == 'did not give a filename':
             filename = url + '.pdf'
@@ -433,7 +433,7 @@ class NANONETSOCR():
                     pdf.ln()
 
                 for wrap in lines:
-                    pdf.cell(0, fontsize_mm, wrap, ln=1)
+                    pdf.multi_cell(0, fontsize_mm, wrap)
 
         pdf.output(filename, 'F')
         print(filename + ' created in current directory')
@@ -508,7 +508,7 @@ class NANONETSOCR():
             
             i = 1
             
-            if not(len(response.json()["result"]) == 1 and len(response.json()["result"][0]["prediction"] ==1)):
+            if not(len(response.json()["result"]) == 1 and len(response.json()["result"][0]["prediction"]) ==1):
                 with open(filename, "w") as my_empty_csv:
                     pass
                 
@@ -543,13 +543,13 @@ class NANONETSOCR():
                 maxrow = 0
                 maxcol = 0
 
-                for el in table['prediction'][0]['cells']:
+                for el in table['cells']:
                     maxrow = max(el['row'],maxrow)
                     maxcol = max(el['col'], maxcol)
 
                 df = pd.DataFrame(np.zeros([maxrow, maxcol])*np.nan)
 
-                for el in table['prediction'][0]['cells']:
+                for el in table['cells']:
                     row = el['row'] - 1
                     col = el['col'] - 1
                     df.iloc[row,col] = el['text']
